@@ -21,8 +21,8 @@ import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.BufferedOutputStream;
 import java.io.File;
-import java.io.FileOutputStream;
 import java.io.IOException;
+import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.Comparator;
 import java.util.List;
@@ -34,50 +34,28 @@ import org.junit.jupiter.api.Test;
 /**
  * Test case for {@link CompositeFileComparator}.
  */
-public class CompositeFileComparatorTest extends ComparatorAbstractTestCase {
+public class CompositeFileComparatorTest extends ComparatorAbstractTest {
 
-    @BeforeEach
-    public void setUp() throws Exception {
-        comparator = new CompositeFileComparator(
-                (AbstractFileComparator) SizeFileComparator.SIZE_COMPARATOR, (AbstractFileComparator) ExtensionFileComparator.EXTENSION_COMPARATOR);
-        reverse = new ReverseFileComparator(comparator);
-        lessFile   = new File(dir, "xyz.txt");
-        equalFile1 = new File(dir, "foo.txt");
-        equalFile2 = new File(dir, "bar.txt");
-        moreFile   = new File(dir, "foo.xyz");
-        if (!lessFile.getParentFile().exists()) {
-            throw new IOException("Cannot create file " + lessFile
-                    + " as the parent directory does not exist");
-        }
+    /**
+     * Test Constructor with null array
+     */
+    @Test
+    public void constructorArray_Null() {
+        final Comparator<File> c = new CompositeFileComparator((Comparator<File>[])null);
+        assertEquals(0, c.compare(lessFile, moreFile), "less,more");
+        assertEquals(0, c.compare(moreFile, lessFile), "more,less");
+        assertEquals("CompositeFileComparator{}", c.toString(), "toString");
+    }
 
-        try (final BufferedOutputStream output3 =
-                new BufferedOutputStream(new FileOutputStream(lessFile))) {
-            TestUtils.generateTestData(output3, 32);
-        }
-        if (!equalFile1.getParentFile().exists()) {
-            throw new IOException("Cannot create file " + equalFile1
-                    + " as the parent directory does not exist");
-        }
-        try (final BufferedOutputStream output2 =
-                new BufferedOutputStream(new FileOutputStream(equalFile1))) {
-            TestUtils.generateTestData(output2, 48);
-        }
-        if (!equalFile2.getParentFile().exists()) {
-            throw new IOException("Cannot create file " + equalFile2
-                    + " as the parent directory does not exist");
-        }
-        try (final BufferedOutputStream output1 =
-                new BufferedOutputStream(new FileOutputStream(equalFile2))) {
-            TestUtils.generateTestData(output1, 48);
-        }
-        if (!moreFile.getParentFile().exists()) {
-            throw new IOException("Cannot create file " + moreFile
-                    + " as the parent directory does not exist");
-        }
-        try (final BufferedOutputStream output =
-                new BufferedOutputStream(new FileOutputStream(moreFile))) {
-            TestUtils.generateTestData(output, 48);
-        }
+    /**
+     * Test Constructor with null Iterable
+     */
+    @Test
+    public void constructorIterable_Null() {
+        final Comparator<File> c = new CompositeFileComparator((Iterable<Comparator<File>>)null);
+        assertEquals(0, c.compare(lessFile, moreFile), "less,more");
+        assertEquals(0, c.compare(moreFile, lessFile), "more,less");
+        assertEquals("CompositeFileComparator{}", c.toString(), "toString");
     }
 
     /**
@@ -95,25 +73,46 @@ public class CompositeFileComparatorTest extends ComparatorAbstractTestCase {
         assertTrue(c.compare(moreFile, lessFile) > 0, "more");
     }
 
-    /**
-     * Test Constructor with null Iterable
-     */
-    @Test
-    public void constructorIterable_Null() {
-        final Comparator<File> c = new CompositeFileComparator((Iterable<Comparator<File>>)null);
-        assertEquals(0, c.compare(lessFile, moreFile), "less,more");
-        assertEquals(0, c.compare(moreFile, lessFile), "more,less");
-        assertEquals("CompositeFileComparator{}", c.toString(), "toString");
-    }
+    @BeforeEach
+    public void setUp() throws Exception {
+        comparator = new CompositeFileComparator(SizeFileComparator.SIZE_COMPARATOR, ExtensionFileComparator.EXTENSION_COMPARATOR);
+        reverse = new ReverseFileComparator(comparator);
+        lessFile   = new File(dir, "xyz.txt");
+        equalFile1 = new File(dir, "foo.txt");
+        equalFile2 = new File(dir, "bar.txt");
+        moreFile   = new File(dir, "foo.xyz");
+        if (!lessFile.getParentFile().exists()) {
+            throw new IOException("Cannot create file " + lessFile
+                    + " as the parent directory does not exist");
+        }
 
-    /**
-     * Test Constructor with null array
-     */
-    @Test
-    public void constructorArray_Null() {
-        final Comparator<File> c = new CompositeFileComparator((Comparator<File>[])null);
-        assertEquals(0, c.compare(lessFile, moreFile), "less,more");
-        assertEquals(0, c.compare(moreFile, lessFile), "more,less");
-        assertEquals("CompositeFileComparator{}", c.toString(), "toString");
+        try (BufferedOutputStream output3 =
+                new BufferedOutputStream(Files.newOutputStream(lessFile.toPath()))) {
+            TestUtils.generateTestData(output3, 32);
+        }
+        if (!equalFile1.getParentFile().exists()) {
+            throw new IOException("Cannot create file " + equalFile1
+                    + " as the parent directory does not exist");
+        }
+        try (BufferedOutputStream output2 =
+                new BufferedOutputStream(Files.newOutputStream(equalFile1.toPath()))) {
+            TestUtils.generateTestData(output2, 48);
+        }
+        if (!equalFile2.getParentFile().exists()) {
+            throw new IOException("Cannot create file " + equalFile2
+                    + " as the parent directory does not exist");
+        }
+        try (BufferedOutputStream output1 =
+                new BufferedOutputStream(Files.newOutputStream(equalFile2.toPath()))) {
+            TestUtils.generateTestData(output1, 48);
+        }
+        if (!moreFile.getParentFile().exists()) {
+            throw new IOException("Cannot create file " + moreFile
+                    + " as the parent directory does not exist");
+        }
+        try (BufferedOutputStream output =
+                new BufferedOutputStream(Files.newOutputStream(moreFile.toPath()))) {
+            TestUtils.generateTestData(output, 48);
+        }
     }
 }
